@@ -1,6 +1,6 @@
 from typing import List
 
-def string_between(string: str, from_str: str, to_str: str) -> str:
+def between(string: str, from_str: str, to_str: str) -> str:
     try:
         return string.split(from_str)[1].split(to_str)[0]
     except:
